@@ -22,6 +22,7 @@ from .core import (
     use_context,
     use_memo,
     use_reducer,
+    use_ref,
     use_side_effect,
     use_state,
     use_state_widget,
@@ -37,6 +38,7 @@ __all__ = [
     "get_widget",
     "use_context",
     "use_memo",
+    "use_ref",
     "use_state",
     "use_state_widget",
     "use_side_effect",
