@@ -333,8 +333,9 @@ def use_reducer(reduce: Callable[[T, U], T], initial_state: T) -> Tuple[T, Calla
     state, set_state = use_state(initial_state)
 
     def dispatch(action):
-        new_state = reduce(state, action)
-        set_state(new_state)
+        def state_updater(state):
+            return reduce(state, action)
+        set_state(state_updater)
 
     return state, dispatch
 
@@ -372,6 +373,19 @@ def use_callback(f, dependencies):
     use_memo(wrapper, args=dependencies)
 
 
+class Ref(Generic[T]):
+    def __init__(self, initial_value: T):
+        self.current = initial_value
+
+
+def use_ref(initial_value: T) -> Ref[T]:
+    def make_ref():
+        return Ref(initial_value)
+
+    ref = use_memo(make_ref, args=[])
+    return ref
+
+
 def provide_context(key: str, obj: Any):
     rc = _get_render_context()
     context = rc.context
